cubicweb/sobjects/ldapparser.py
changeset 11252 6b1d09ef0c45
parent 11057 0b59724cb3f2
child 11719 36443c44b9a5
--- a/cubicweb/sobjects/ldapparser.py	Tue Jun 30 10:05:46 2015 +0200
+++ b/cubicweb/sobjects/ldapparser.py	Wed Jul 01 08:42:44 2015 +0200
@@ -184,10 +184,10 @@
                 # not found, create it. first forge an external id
                 extuser.values.setdefault('use_email', []).append(emailextid)
                 yield importer.ExtEntity('EmailAddress', emailextid, dict(address=[emailaddr]))
-            elif self.sourceuris:
-                # pop from sourceuris anyway, else email may be removed by the
+            elif self.source_uris:
+                # pop from source_uris anyway, else email may be removed by the
                 # source once import is finished
-                self.sourceuris.pop(emailextid, None)
+                self.source_uris.pop(emailextid, None)
             # XXX else check use_email relation?
 
     def handle_deletion(self, config, cnx, myuris):